@@ -1,9 +1,9 @@
 class Request():
     """ステートマシンからステートへ与えられる引数のまとまり"""
 
-    def __init__(self, context, intermachine, edge_path=[]):
+    def __init__(self, context, intermachine, state_path=[]):
         self._context = context
-        self._edge_path = edge_path
+        self._state_path = state_path
         self._intermachine = intermachine
 
     @property
@@ -13,14 +13,14 @@ class Request():
         return self._context
 
     @property
-    def edge_path(self):
-        """辺パス
+    def state_path(self):
+        """状態パス
         Examples
         --------
         list
             ["this","is","a","edge","path"]
         """
-        return self._edge_path
+        return self._state_path
 
     @property
     def intermachine(self):
